@@ -13,9 +13,9 @@ def validate_instagram(user):
         'X-Requested-With': "XMLHttpRequest",
         'Referer': f"https://www.instagram.com/{user}/",
     }
-    
+
     try:
-        response = httpx.get(url, headers=headers, timeout = 15.0)
+        response = httpx.get(url, headers=headers, timeout = 3.0)
         status = response.status_code
 
         if status == 200:
@@ -31,12 +31,6 @@ def validate_instagram(user):
         return 2
 
 if __name__ == "__main__":
-   try:
-       import httpx
-   except ImportError:
-       print("Error: 'httpx' library is not installed.")
-       exit()
-
    user = input ("Username?: ").strip()
    result = validate_instagram(user)
 
