@@ -31,12 +31,6 @@ def validate_reddit(user):
         return 2
 
 if __name__ == "__main__":
-   try:
-       import httpx
-   except ImportError:
-       print("Error: 'httpx' library is not installed.")
-       exit()
-
    user = input ("Username?: ").strip()
    result = validate_reddit(user)
 
