@@ -1,14 +1,15 @@
 import httpx
 import json
+from colorama import Fore, Style
 from httpx import ConnectError, TimeoutException
 
 def validate_x(user):
     url = "https://api.twitter.com/i/users/username_available.json"
-    
+
     params = {
         "username": user,
-        "full_name": "Test User",
-        "email": "test@example.com"
+        "full_name": "John Doe",
+        "email": "johndoe07@gmail.com"
     }
 
     headers = {
@@ -19,17 +20,20 @@ def validate_x(user):
     try:
         response = httpx.get(url, params=params, headers=headers, timeout = 3.0)
         status = response.status_code
-
+       # print(response.text)
         if status in [401, 403, 429]:
             return 2
-        
+
+
         elif status == 200:
             data = response.json()
-            
             if data.get('valid') is True:
                 return 1
             elif data.get('reason') == 'taken':
                 return 0
+            elif (data.get('reason') == "improper_format" or data.get('reason') == "invalid_username"):
+                print("\n" +"  "+f"{Fore.CYAN}X says: {data.get('desc')}{Style.RESET_ALL}")
+                return 2
             else:
                 return 2
 
@@ -39,12 +43,6 @@ def validate_x(user):
         return 2
 
 if __name__ == "__main__":
-   try:
-       import httpx
-   except ImportError:
-       print("Error: 'httpx' library is not installed.")
-       exit()
-
    user = input ("Username?: ").strip()
    result = validate_x(user)
 
